==> scalts-0.4.0.tgz: package/src/Either.js <==
/* tslint:disable:no-use-before-declare */
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var Optional_1 = require('./Optional');
/**
 * The right side of the disjoint union, as opposed to the Left side.
 * @param b
 * @constructor
 */
function Right(b) {
    return new RightImpl(b);
}
exports.Right = Right;
/**
 * The left side of the disjoint union, as opposed to the Right side.
 * @param a
 * @constructor
 */
function Left(a) {
    return new LeftImpl(a);
}
exports.Left = Left;
function Either(cond, left, right) {
    return !cond ? Left(left()) : Right(right());
}
exports.Either = Either;
/**
 * Either implementation.
 */
var EitherImpl = (function () {
    function EitherImpl() {
    }
    EitherImpl.prototype.toString = function () {
        return this.isLeft ? "Left(" + this.value + ")" : "Right(" + this.value + ")";
    };
    /** @override */
    EitherImpl.prototype.left = function () {
        return new LeftProjection(this);
    };
    /** @override */
    EitherImpl.prototype.right = function () {
        return new RightProjection(this);
    };
    /** @override */
    EitherImpl.prototype.fold = function (fa, fb) {
        return this.isLeft ? fa(this.value) : fb(this.value);
    };
    /** @override */
    EitherImpl.prototype.swap = function () {
        return this.isLeft ? Right(this.value) : Left(this.value);
    };
    /** @override */
    EitherImpl.prototype.foreach = function (f) {
        if (this.isRight) {
            f(this.value);
        }
    };
    /** @override */
    EitherImpl.prototype.getOrElse = function (dv) {
        return this.isLeft ? dv() : this.value;
    };
    /** @override */
    EitherImpl.prototype.contains = function (elem) {
        return this.isRight && this.value === elem;
    };
    /** @override */
    EitherImpl.prototype.forall = function (f) {
        return this.isLeft || f(this.value);
    };
    /** @override */
    EitherImpl.prototype.exists = function (f) {
        return this.isRight && f(this.value);
    };
    /** @override */
    EitherImpl.prototype.map = function (f) {
        return this.isLeft ? Left(this.value) : Right(f(this.value));
    };
    /** @override */
    EitherImpl.prototype.flatMap = function (f) {
        return this.isLeft ? Left(this.value) : f(this.value);
    };
    /** @override */
    EitherImpl.prototype.toOptional = function () {
        return this.isLeft ? Optional_1.None : Optional_1.Some(this.value);
    };
    /** @override */
    EitherImpl.prototype.match = function (pf) {
        return this.fold(pf.Left, pf.Right);
    };
    EitherImpl.prototype.chain = function (ob) {
        return new EitherBuilder1(this, ob);
    };
    EitherImpl.prototype.apply1 = function (ob, f) {
        return this.flatMap(function (a) { return ob.map(function (b) { return f(a, b); }); });
    };
    EitherImpl.prototype.apply2 = function (ob, oc, f) {
        return this.flatMap(function (a) { return ob.flatMap(function (b) { return oc.map(function (c) { return f(a, b, c); }); }); });
    };
    EitherImpl.prototype.apply3 = function (ob, oc, od, f) {
        return this.flatMap(function (a) { return ob.flatMap(function (b) { return oc.flatMap(function (c) { return od.map(function (d) { return f(a, b, c, d); }); }); }); });
    };
    EitherImpl.prototype.apply4 = function (ob, oc, od, oe, f) {
        return this.flatMap(function (a) { return ob.flatMap(function (b) { return oc.flatMap(function (c) { return od.flatMap(function (d) { return oe.map(function (e) { return f(a, b, c, d, e); }); }); }); }); });
    };
    EitherImpl.prototype.apply5 = function (ob, oc, od, oe, of, f) {
        return this.flatMap(function (a) { return ob.flatMap(function (b) { return oc.flatMap(function (c) { return od.flatMap(function (d) { return oe.flatMap(function (e) { return of.map(function (ff) { return f(a, b, c, d, e, ff); }); }); }); }); }); });
    };
    return EitherImpl;
}());
//------------------------------------
//
// Implementation section.
//
//------------------------------------
/**
 * Left implementation.
 */
var LeftImpl = (function (_super) {
    __extends(LeftImpl, _super);
    function LeftImpl(value) {
        _super.call(this);
        this.value = value;
        this.isLeft = true;
        this.isRight = false;
    }
    return LeftImpl;
}(EitherImpl));
/**
 * Right implementation
 */
var RightImpl = (function (_super) {
    __extends(RightImpl, _super);
    function RightImpl(value) {
        _super.call(this);
        this.value = value;
        this.isLeft = false;
        this.isRight = true;
    }
    return RightImpl;
}(EitherImpl));
/**
 * Left project.
 */
var LeftProjection = (function () {
    function LeftProjection(self) {
        this.self = self;
    }
    LeftProjection.prototype.toString = function () {
        return "LeftProjection(" + this.self.toString() + ")";
    };
    LeftProjection.prototype.get = function () {
        if (this.self.isLeft) {
            return this.self.value;
        }
        else {
            throw new Error('cannot get Left value');
        }
    };
    LeftProjection.prototype.foreach = function (f) {
        if (this.self.isLeft) {
            f(this.self.value);
        }
    };
    LeftProjection.prototype.getOrElse = function (x) {
        return this.self.isLeft ? this.self.value : x();
    };
    LeftProjection.prototype.forall = function (f) {
        return this.self.isLeft ? f(this.self.value) : true;
    };
    LeftProjection.prototype.exists = function (f) {
        return this.self.isLeft ? f(this.self.value) : false;
    };
    LeftProjection.prototype.filter = function (f) {
        if (this.self.isLeft) {
            return f(this.self.value) ? Optional_1.Optional.apply(this.self) : Optional_1.None;
        }
        else {
            return Optional_1.None;
        }
    };
    LeftProjection.prototype.map = function (f) {
        return this.self.isLeft ? Left(f(this.self.value)) : this.self;
    };
    LeftProjection.prototype.flatMap = function (f) {
        return this.self.isLeft ? f(this.self.value) : this.self;
    };
    LeftProjection.prototype.toOptional = function () {
        return this.self.isLeft ? Optional_1.Optional.apply(this.self.value) : Optional_1.None;
    };
    return LeftProjection;
}());
exports.LeftProjection = LeftProjection;
/**
 * Left project.
 */
var RightProjection = (function () {
    function RightProjection(self) {
        this.self = self;
    }
    RightProjection.prototype.toString = function () {
        return "RightProjection(" + this.self.toString() + ")";
    };
    RightProjection.prototype.get = function () {
        if (this.self.isRight) {
            return this.self.value;
        }
        else {
            throw new Error('cannot get Right value');
        }
    };
    RightProjection.prototype.foreach = function (f) {
        if (this.self.isRight) {
            f(this.self.value);
        }
    };
    RightProjection.prototype.getOrElse = function (x) {
        return this.self.isRight ? this.self.value : x();
    };
    RightProjection.prototype.forall = function (f) {
        return this.self.isRight ? f(this.self.value) : true;
    };
    RightProjection.prototype.exists = function (f) {
        return this.self.isRight ? f(this.self.value) : false;
    };
    RightProjection.prototype.filter = function (f) {
        if (this.self.isRight) {
            return f(this.self.value) ? Optional_1.Optional.apply(this.self) : Optional_1.None;
        }
        else {
            return Optional_1.None;
        }
    };
    RightProjection.prototype.map = function (f) {
        return this.self.isLeft ? this.self : Right(f(this.self.value));
    };
    RightProjection.prototype.flatMap = function (f) {
        return this.self.isLeft ? this.self : f(this.self.value);
    };
    RightProjection.prototype.toOptional = function () {
        return this.self.isRight ? Optional_1.Optional.apply(this.self.value) : Optional_1.None;
    };
    return RightProjection;
}());
exports.RightProjection = RightProjection;
var EitherBuilder1 = (function () {
    function EitherBuilder1(oa, ob) {
        this.oa = oa;
        this.ob = ob;
    }
    EitherBuilder1.prototype.run = function (f) {
        return this.oa.apply1(this.ob, f);
    };
    EitherBuilder1.prototype.chain = function (oc) {
        return new EitherBuilder2(this.oa, this.ob, oc);
    };
    return EitherBuilder1;
}());
exports.EitherBuilder1 = EitherBuilder1;
var EitherBuilder2 = (function () {
    function EitherBuilder2(oa, ob, oc) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
    }
    EitherBuilder2.prototype.run = function (f) {
        return this.oa.apply2(this.ob, this.oc, f);
    };
    EitherBuilder2.prototype.chain = function (od) {
        return new EitherBuilder3(this.oa, this.ob, this.oc, od);
    };
    return EitherBuilder2;
}());
exports.EitherBuilder2 = EitherBuilder2;
var EitherBuilder3 = (function () {
    function EitherBuilder3(oa, ob, oc, od) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
    }
    EitherBuilder3.prototype.run = function (f) {
        return this.oa.apply3(this.ob, this.oc, this.od, f);
    };
    EitherBuilder3.prototype.chain = function (oe) {
        return new EitherBuilder4(this.oa, this.ob, this.oc, this.od, oe);
    };
    return EitherBuilder3;
}());
exports.EitherBuilder3 = EitherBuilder3;
var EitherBuilder4 = (function () {
    function EitherBuilder4(oa, ob, oc, od, oe) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
        this.oe = oe;
    }
    EitherBuilder4.prototype.run = function (f) {
        return this.oa.apply4(this.ob, this.oc, this.od, this.oe, f);
    };
    EitherBuilder4.prototype.chain = function (of) {
        return new EitherBuilder5(this.oa, this.ob, this.oc, this.od, this.oe, of);
    };
    return EitherBuilder4;
}());
exports.EitherBuilder4 = EitherBuilder4;
var EitherBuilder5 = (function () {
    function EitherBuilder5(oa, ob, oc, od, oe, of) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
        this.oe = oe;
        this.of = of;
    }
    EitherBuilder5.prototype.run = function (f) {
        return this.oa.apply5(this.ob, this.oc, this.od, this.oe, this.of, f);
    };
    return EitherBuilder5;
}());
exports.EitherBuilder5 = EitherBuilder5;

==> scalts-0.6.0.tgz: package/src/Either.js <==
/* tslint:disable:no-use-before-declare */
"use strict";
const Optional_1 = require("./Optional");
/**
 * The right side of the disjoint union, as opposed to the Left side.
 * @param b
 * @constructor
 */
function Right(b) {
    return new RightImpl(b);
}
exports.Right = Right;
/**
 * The left side of the disjoint union, as opposed to the Right side.
 * @param a
 * @constructor
 */
function Left(a) {
    return new LeftImpl(a);
}
exports.Left = Left;
function Either(cond, left, right) {
    return !cond ? Left(left()) : Right(right());
}
exports.Either = Either;
/**
 * Either implementation.
 */
class EitherImpl {
    toString() {
        return this.isLeft ? `Left(${this.value})` : `Right(${this.value})`;
    }
    /** @override */
    left() {
        return new LeftProjection(this);
    }
    /** @override */
    right() {
        return new RightProjection(this);
    }
    /** @override */
    fold(fa, fb) {
        return this.isLeft ? fa(this.value) : fb(this.value);
    }
    /** @override */
    swap() {
        return this.isLeft ? Right(this.value) : Left(this.value);
    }
    /** @override */
    foreach(f) {
        if (this.isRight) {
            f(this.value);
        }
    }
    /** @override */
    getOrElse(dv) {
        return this.isLeft ? dv() : this.value;
    }
    /** @override */
    contains(elem) {
        return this.isRight && this.value === elem;
    }
    /** @override */
    forall(f) {
        return this.isLeft || f(this.value);
    }
    /** @override */
    exists(f) {
        return this.isRight && f(this.value);
    }
    /** @override */
    map(f) {
        return this.isLeft ? Left(this.value) : Right(f(this.value));
    }
    /** @override */
    flatMap(f) {
        return this.isLeft ? Left(this.value) : f(this.value);
    }
    /** @override */
    toOptional() {
        return this.isLeft ? Optional_1.None : Optional_1.Some(this.value);
    }
    /** @override */
    match(pf) {
        return this.fold(pf.Left, pf.Right);
    }
    chain(ob) {
        return new EitherBuilder1(this, ob);
    }
    apply1(ob, f) {
        return this.flatMap(a => ob.map(b => f(a, b)));
    }
    apply2(ob, oc, f) {
        return this.flatMap(a => ob.flatMap(b => oc.map(c => f(a, b, c))));
    }
    apply3(ob, oc, od, f) {
        return this.flatMap(a => ob.flatMap(b => oc.flatMap(c => od.map(d => f(a, b, c, d)))));
    }
    apply4(ob, oc, od, oe, f) {
        return this.flatMap(a => ob.flatMap(b => oc.flatMap(c => od.flatMap(d => oe.map(e => f(a, b, c, d, e))))));
    }
    apply5(ob, oc, od, oe, of, f) {
        return this.flatMap(a => ob.flatMap(b => oc.flatMap(c => od.flatMap(d => oe.flatMap(e => of.map(ff => f(a, b, c, d, e, ff)))))));
    }
}
//------------------------------------
//
// Implementation section.
//
//------------------------------------
/**
 * Left implementation.
 */
class LeftImpl extends EitherImpl {
    constructor(value) {
        super();
        this.value = value;
        this.isLeft = true;
        this.isRight = false;
    }
}
/**
 * Right implementation
 */
class RightImpl extends EitherImpl {
    constructor(value) {
        super();
        this.value = value;
        this.isLeft = false;
        this.isRight = true;
    }
}
/**
 * Left project.
 */
class LeftProjection {
    constructor(self) {
        this.self = self;
    }
    toString() {
        return `LeftProjection(${this.self.toString()})`;
    }
    get() {
        if (this.self.isLeft) {
            return this.self.value;
        }
        else {
            throw new Error('cannot get Left value');
        }
    }
    foreach(f) {
        if (this.self.isLeft) {
            f(this.self.value);
        }
    }
    getOrElse(x) {
        return this.self.isLeft ? this.self.value : x();
    }
    forall(f) {
        return this.self.isLeft ? f(this.self.value) : true;
    }
    exists(f) {
        return this.self.isLeft ? f(this.self.value) : false;
    }
    filter(f) {
        if (this.self.isLeft) {
            return f(this.self.value) ? Optional_1.Optional.apply(this.self) : Optional_1.None;
        }
        else {
            return Optional_1.None;
        }
    }
    map(f) {
        return this.self.isLeft ? Left(f(this.self.value)) : this.self;
    }
    flatMap(f) {
        return this.self.isLeft ? f(this.self.value) : this.self;
    }
    toOptional() {
        return this.self.isLeft ? Optional_1.Optional.apply(this.self.value) : Optional_1.None;
    }
}
exports.LeftProjection = LeftProjection;
/**
 * Left project.
 */
class RightProjection {
    constructor(self) {
        this.self = self;
    }
    toString() {
        return `RightProjection(${this.self.toString()})`;
    }
    get() {
        if (this.self.isRight) {
            return this.self.value;
        }
        else {
            throw new Error('cannot get Right value');
        }
    }
    foreach(f) {
        if (this.self.isRight) {
            f(this.self.value);
        }
    }
    getOrElse(x) {
        return this.self.isRight ? this.self.value : x();
    }
    forall(f) {
        return this.self.isRight ? f(this.self.value) : true;
    }
    exists(f) {
        return this.self.isRight ? f(this.self.value) : false;
    }
    filter(f) {
        if (this.self.isRight) {
            return f(this.self.value) ? Optional_1.Optional.apply(this.self) : Optional_1.None;
        }
        else {
            return Optional_1.None;
        }
    }
    map(f) {
        return this.self.isLeft ? this.self : Right(f(this.self.value));
    }
    flatMap(f) {
        return this.self.isLeft ? this.self : f(this.self.value);
    }
    toOptional() {
        return this.self.isRight ? Optional_1.Optional.apply(this.self.value) : Optional_1.None;
    }
}
exports.RightProjection = RightProjection;
class EitherBuilder1 {
    constructor(oa, ob) {
        this.oa = oa;
        this.ob = ob;
    }
    run(f) {
        return this.oa.apply1(this.ob, f);
    }
    chain(oc) {
        return new EitherBuilder2(this.oa, this.ob, oc);
    }
}
exports.EitherBuilder1 = EitherBuilder1;
class EitherBuilder2 {
    constructor(oa, ob, oc) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
    }
    run(f) {
        return this.oa.apply2(this.ob, this.oc, f);
    }
    chain(od) {
        return new EitherBuilder3(this.oa, this.ob, this.oc, od);
    }
}
exports.EitherBuilder2 = EitherBuilder2;
class EitherBuilder3 {
    constructor(oa, ob, oc, od) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
    }
    run(f) {
        return this.oa.apply3(this.ob, this.oc, this.od, f);
    }
    chain(oe) {
        return new EitherBuilder4(this.oa, this.ob, this.oc, this.od, oe);
    }
}
exports.EitherBuilder3 = EitherBuilder3;
class EitherBuilder4 {
    constructor(oa, ob, oc, od, oe) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
        this.oe = oe;
    }
    run(f) {
        return this.oa.apply4(this.ob, this.oc, this.od, this.oe, f);
    }
    chain(of) {
        return new EitherBuilder5(this.oa, this.ob, this.oc, this.od, this.oe, of);
    }
}
exports.EitherBuilder4 = EitherBuilder4;
class EitherBuilder5 {
    constructor(oa, ob, oc, od, oe, of) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
        this.oe = oe;
        this.of = of;
    }
    run(f) {
        return this.oa.apply5(this.ob, this.oc, this.od, this.oe, this.of, f);
    }
}
exports.EitherBuilder5 = EitherBuilder5;
